# Copyright (C) 2019 Alteryx, Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
"""Definition of the IdentityTransformer."""

import sklearn.base


class IdentityTransformer(sklearn.base.TransformerMixin):
    """Transformer used for applying typing to a dataframe."""

    def __init__(self, **kwargs):
        pass

    def transform(self, x, y=None, **kwargs):
        """No operation."""
        return x

    def fit(self, x, y=None, **kwargs):
        """No operation."""
        return self
